@@ -1,9 +1,10 @@
 from abc import ABC, abstractmethod
-from typing import TYPE_CHECKING, Any, Callable, Dict, List, Union
+from typing import TYPE_CHECKING, Any, Callable, Dict, List, Type, Union
 
 if TYPE_CHECKING:
     from vkbottle.dispatch.rules import ABCRule
     from vkbottle.dispatch.views import ABCView
+    from vkbottle.dispatch.views.abc import ABCMessageView, ABCRawEventView
     from vkbottle.tools.dev.mini_types.base.message import BaseMessageMin
 
     LabeledMessageHandler = Callable[..., Callable[["BaseMessageMin"], Any]]
@@ -11,6 +12,12 @@ if TYPE_CHECKING:
 
 
 class ABCLabeler(ABC):
+    message_view: "ABCMessageView"
+    raw_event_view: "ABCRawEventView"
+    custom_rules: Dict[str, Type["ABCRule"]]
+    auto_rules: List["ABCRule"]
+    rule_config: Dict[str, Any]
+
     @abstractmethod
     def message(self, *rules: "ABCRule", **custom_rules) -> "LabeledMessageHandler":
         pass
